==> openx-2.5.66-beta.tar.gz: openx-2.5.66-beta/lib/max/Dal/DataObjects/Variables.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Variables.php 18135 2008-03-27 13:21:12Z andrew.hill@openx.org $
*/

/**
 * Table Definition for variables
 */
require_once 'DB_DataObjectCommon.php';

class DataObjects_Variables extends DB_DataObjectCommon
{
    var $onDeleteCascade = true;
    var $refreshUpdatedFieldIfExists = true;
    ###START_AUTOCODE
    /* the code below is auto generated do not remove the above tag */

    var $__table = 'variables';                       // table name
    var $variableid;                      // int(9)  not_null primary_key unsigned auto_increment
    var $trackerid;                       // int(9)  not_null multiple_key
    var $name;                            // string(250)  not_null
    var $description;                     // string(250)
    var $datatype;                        // string(7)  not_null enum
    var $purpose;                         // string(12)  enum
    var $reject_if_empty;                 // int(1)  not_null unsigned
    var $is_unique;                       // int(11)  not_null multiple_key
    var $unique_window;                   // int(11)  not_null
    var $variablecode;                    // string(255)  not_null
    var $hidden;                          // string(1)  not_null enum
    var $updated;                         // datetime(19)  not_null binary

    /* ZE2 compatibility trick*/
    function __clone() { return $this;}

    /* Static get */
    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('DataObjects_Variables',$k,$v); }

    var $defaultValues = array(
                'trackerid' => 0,
                'datatype' => 'numeric',
                'reject_if_empty' => 0,
                'is_unique' => 0,
                'unique_window' => 0,
                'hidden' => 'f',
                );

    /* the code above is auto generated do not remove the tag below */
    ###END_AUTOCODE

    function _auditEnabled()
    {
        return true;
    }

    function _getContextId()
    {
        return $this->variableid;
    }

    function _getContext()
    {
        return 'Variable';
    }

    /**
     * A private method to return the account ID of the
     * account that should "own" audit trail entries for
     * this entity type; NOT related to the account ID
     * of the currently active account performing an
     * action.
     *
     * @return integer The account ID to insert into the
     *                 "account_id" column of the audit trail
     *                 database table.
     */
    function getOwningAccountId()
    {
        return $this->_getOwningAccountIdFromParent('trackers', 'trackerid');
    }

    /**
     * build a variable specific audit array
     *
     * @param integer $actionid
     * @param array $aAuditFields
     */
    function _buildAuditArray($actionid, &$aAuditFields)
    {
        $aAuditFields['key_desc']   = $this->name;
    }

}

?>

==> openx-2.5.67-beta.tar.gz: openx-2.5.67-beta/lib/max/Dal/DataObjects/Variables.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Variables.php 19860 2008-05-06 09:47:57Z david.keen@openx.org $
*/

/**
 * Table Definition for variables
 */
require_once 'DB_DataObjectCommon.php';

class DataObjects_Variables extends DB_DataObjectCommon
{
    var $onDeleteCascade = true;
    var $refreshUpdatedFieldIfExists = true;
    ###START_AUTOCODE
    /* the code below is auto generated do not remove the above tag */

    var $__table = 'variables';                       // table name
    var $variableid;                      // int(9)  not_null primary_key unsigned auto_increment
    var $trackerid;                       // int(9)  not_null multiple_key
    var $name;                            // string(750)  not_null
    var $description;                     // string(750)
    var $datatype;                        // string(21)  not_null enum
    var $purpose;                         // string(36)  enum
    var $reject_if_empty;                 // int(1)  not_null unsigned
    var $is_unique;                       // int(11)  not_null multiple_key
    var $unique_window;                   // int(11)  not_null
    var $variablecode;                    // string(765)  not_null
    var $hidden;                          // string(3)  not_null enum
    var $updated;                         // datetime(19)  not_null binary

    /* ZE2 compatibility trick*/
    function __clone() { return $this;}

    /* Static get */
    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('DataObjects_Variables',$k,$v); }

    var $defaultValues = array(
                'trackerid' => 0,
                'datatype' => 'numeric',
                'reject_if_empty' => 0,
                'is_unique' => 0,
                'unique_window' => 0,
                'hidden' => 'f',
                );

    /* the code above is auto generated do not remove the tag below */
    ###END_AUTOCODE

    function _auditEnabled()
    {
        return true;
    }

    function _getContextId()
    {
        return $this->variableid;
    }

    function _getContext()
    {
        return 'Variable';
    }

    /**
     * A method to return an array of account IDs of the account(s) that
     * should "own" any audit trail entries for this entity type; these
     * are NOT related to the account ID of the currently active account
     * (which is performing some kind of action on the entity), but is
     * instead related to the type of entity, and where in the account
     * heirrachy the entity is located.
     *
     * @return array An array containing up to three indexes:
     *                  - "OA_ACCOUNT_ADMIN" or "OA_ACCOUNT_MANAGER":
     *                      Contains the account ID of the manager account
     *                      that needs to be able to see the audit trail
     *                      entry, or, the admin account, if the entity
     *                      is a special case where only the admin account
     *                      should see the entry.
     *                  - "OA_ACCOUNT_ADVERTISER":
     *                      Contains the account ID of the advertiser account
     *                      that needs to be able to see the audit trail
     *                      entry, if such an account exists.
     *                  - "OA_ACCOUNT_TRAFFICKER":
     *                      Contains the account ID of the trafficker account
     *                      that needs to be able to see the audit trail
     *                      entry, if such an account exists.
     */
    function getOwningAccountIds()
    {
        // Variables don't have an account_id, get it from the
        // parent tracker (stored in the "trackers" table) using
        // the "trackerid" key
        return parent::getOwningAccountIds('trackers', 'trackerid');
    }

    /**
     * build a variable specific audit array
     *
     * @param integer $actionid
     * @param array $aAuditFields
     */
    function _buildAuditArray($actionid, &$aAuditFields)
    {
        $aAuditFields['key_desc']   = $this->name;
    }

}

?>
